@@ -1,7 +1,7 @@
 /************************************************************************
  * ifchk.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2016 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2017 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.0.6                                     *
+ * Version:         1.0.7                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -87,7 +87,6 @@ int main( int argc, char **argv )
     struct conf *curParam;		/* Pointer to current ifchk configuration parameter. */
     FILE *errfilefd = NULL;		/* Error log file pointer for fopen() */
     char paramBuf[STRBUFSZ];		/* Configuration parameter buffer. */
-    char sigNumBuf[SNBUFSZ];		/* Signal log buffer for ifchk shutdown proceedure. */
     int ifStatusSecs = 0;		/* Interface status scan frequency. */
     int ifMetricSecs = 0;		/* Interface metrics dump frequency. */
     int disablePromisc = 0;		/* Enable/disable promiscuous interface shutdown. */
@@ -498,9 +497,8 @@ int main( int argc, char **argv )
      }
 
     /*
-     * Call sigsetInit() to initialize our POSIX signal set,
-     * newMask. In doing so, we add SIGINT, SIGTERM, SIGUSR1
-     * and SIGUSR2.
+     * Call sigsetInit() to create out POSIX signal set, newMask.
+     * Then, initialize newMask with SIGINT, SIGTERM, SIGUSR1/2.
      */
     newMask = sigsetInit();
 
@@ -524,115 +522,49 @@ int main( int argc, char **argv )
      }
 
     /*
-     * Program signal event loop.
+     * Enter program's main event loop, and
+     * sigwait() for the delivery of signals.
      */
-    for( ;; )
+    if( evtLoop( newMask, disablePromisc ) != 0 )
     {
-        /*
-         * We sigwait() here for signals. This loop determines our res-
-         * ponse to the reception of SIGINT, SIGTERM, SIGUSR1 & SIGUSR2.
-         */
-        if( sigwait( &newMask, &sig ) != 0 )
+        exit( EXIT_FAILURE );
+     }
+
+    /*
+     * We caught SIGINT or SIGTERM and exited evtLoop().
+     * Initiate program cleanu, and subsequent shutdown.
+     */
+
+    /*
+     * Remove the /tmp/.ifchk.pid write lock and then delete the file.
+     */
+    if( lockCtl( UNLOCK ) != 0 )
+    {
+        exit( EXIT_FAILURE );
+     }
+
+    /*
+     * If we're running as a daemon, close() the ifchk.errlog file.
+     */
+    if( FFlag == FALSE )
+    {
+        if( close( fileno( errfilefd ) ) != 0 )
         {
-            errHandler( "ERROR: sigwait(): signal selection failed: %s\n", strerror( errno ) );
+            errHandler( "ERROR: close(): could not close %s: %s\n", errFile,
+                                                             strerror( errno ) );
             exit( EXIT_FAILURE );
          }
+     }
 
-        /*
-         * We caught SIGINT or SIGTERM - initiate
-         * program cleanup and subsequent shutdown.
-         */
-        if( ( sig == SIGINT ) || ( sig == SIGTERM ) )
-        {
-            /*
-             * Remove the /tmp/.ifchk.pid write lock and then delete the file.
-             */
-            if( lockCtl( UNLOCK ) != 0 )
-            {
-                exit( EXIT_FAILURE );
-             }
+    /*
+     * If we're running as a foreground process, we
+     * write a program termination message to STDOUT.
+     */
+    printf( "ifchk[%d]: ifchk caught SIGINT or SIGTERM, exiting\n" );
 
-            /*
-             * If we're running as a daemon, close() the ifchk.errlog file.
-             */
-            if( FFlag == FALSE )
-            {
-                if( close( fileno( errfilefd ) ) != 0 )
-                {
-                    errHandler( "ERROR: close(): could not close %s: %s\n", errFile,
-                                                                   strerror( errno ) );
-                    exit( EXIT_FAILURE );
-                 }
-             }
-
-            /*
-             * If we're running as a foreground process, we
-             * write a program termination message to STDOUT.
-             */
-            printf( "ifchk[%d]: ifchk caught signal %d, exiting\n", getpid(), sig );
-
-            memset( sigNumBuf, '\000', sizeof( sigNumBuf ) );
-
-            if( snprintf( sigNumBuf, sizeof( sigNumBuf ), "%d", sig ) < 1 )
-            {
-                errHandler( "ERROR: snprintf(): could not write to character buffer: %s\n",
-                                                                          strerror( errno ) );
-                exit( EXIT_FAILURE );
-             }
-
-            sigNumBuf[SNBUFSZ - 1] = '\000';
-
-            if( ( writeLog( LOG_NOTICE, "ifchk caught signal %s, exiting\n", sigNumBuf ) ) != 0 )
-            {
-                exit( EXIT_FAILURE );
-             }
-
-            exit( EXIT_SUCCESS );
-         }
-
-        /*
-         * We caught SIGUSR1 - perform an interface
-         * status scan when we call ifStat(), below.
-         */
-        if( sig == SIGUSR1 )
-        {
-            iFlag = FALSE;
-
-            /*
-             * If disablePromisc is set, report and shutdown promiscuous interfaces.
-             */
-            if( disablePromisc == 1 )
-            {
-                dFlag = TRUE;
-             }
-
-            /*
-             * If disablePromisc is not set, report promiscuous interfaces only.
-             */
-            else
-            {
-                nullFlag = TRUE;
-             }
-         }
-
-        /*
-         * We caught SIGUSR2 - perform an interface
-         * metrics dump when we call ifStat(), below.
-         */
-        if( sig == SIGUSR2 )
-        {
-            dFlag = FALSE;
-            nullFlag = FALSE;
-            iFlag = TRUE;
-         }
-
-        /*
-         * Call ifStat().
-         */
-        if( ifStat() != 0 )
-        {
-            exit( EXIT_FAILURE );
-         }
+    if( ( writeLog( LOG_NOTICE, "ifchk caught SIGINT or SIGTERM, exiting\n" ) ) != 0 )
+    {
+        exit( EXIT_FAILURE );
      }
 
     return (0);
