@@ -1,7 +1,7 @@
 /************************************************************************
  * psig.c                                                               *
  *                                                                      *
- * Copyright (C) 2002 - 2016 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2017 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous     *
  *                  mode detection and handling.                 *
  *                                                               *
- * Version:         1.0.6                                        *
+ * Version:         1.0.7                                        *
  *                                                               *
  * ------------------------------------------------------------- *
  *                                                               *
@@ -75,15 +75,6 @@ sigset_t sigsetInit()
         exit( EXIT_FAILURE );
      }
 
-    /*
-     * Add SIGHUP to newMask.
-     */
-    if( sigaddset( &newMask, SIGHUP ) != 0 )
-    {
-        errHandler( "ERROR: sigaddset(): could not add SIGHUP to signal set: %s\n",
-                                                                  strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
     /*
      * Add SIGINT to newMask.
      */
